==> 1.0.1.tar.gz: lib/model/api_resp.dart <==
class commonResp {
  late String sequence;
  late String returnCode;
  late String returnMsg;

  commonResp();

  commonResp.fromJson(Map<String, dynamic> json)
      : sequence = json['sequence'],
        returnCode = json['returnCode'],
        returnMsg = json['returnCode'];
}

class getUUIDResp extends commonResp{
  var cnts;
  var device_uuid;
  var device_id;

  getUUIDResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device_uuid = json['returnData']['device_uuid'],
        device_id = json['returnData']['device_id'];
}

class infoUpdateResp extends commonResp{
  var cnts;
  var device_uuid;
  var device_id;

  infoUpdateResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device_uuid = json['returnData']['device_uuid'],
        device_id = json['returnData']['device_id'];
}

class contentQueryResp extends commonResp{
  var cnts;
  var title;
  var message;
  var status_time;
  var content_type;
  var content;

  contentQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        title = json['returnData']['title'],
        message = json['returnData']['message'],
        status_time = json['returnData']['status_time'],
        content_type = json['returnData']['content_type'],
        content = json['returnData']['content'];
}

class messageQueryResp extends commonResp{
  var cnts;
  List<messageQueryRows> ?rows;

  messageQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        rows = (json['returnData']['rows'] as List) == null ? null : (json['returnData']['rows'] as List)
            .map((json) => new messageQueryRows.fromJson(json))
            .toList();
}

class messageQueryRows {
  var message_id;
  var is_private;
  var category;
  var title;
  var message;
  var param;
  var status_time;
  var date;
  var time;
  var is_read;

  messageQueryRows({message_id, is_private, category, title, message, param, status_time, date, time, is_read});

  factory messageQueryRows.fromJson(Map<String, dynamic> json) {
    return messageQueryRows(
        message_id : json['message_id'],
        is_private : json['is_private'],
        category : json['category'],
        title : json['title'],
        message : json['message'],
        param : json['param'],
        status_time : json['status_time'],
        date : json['date'],
        time : json['time'],
        is_read : json['is_read']
    );
  }
}

class statusQueryResp extends commonResp{
  var is_receive;
  var enable_curfew;
  var start_time;
  var end_time;
  var cnts;
  List<statusQueryRows> ?rows;

  statusQueryResp.fromJson(Map<String, dynamic> json)
      : is_receive = json['returnData']['is_receive'],
        enable_curfew = json['returnData']['enable_curfew'],
        start_time = json['returnData']['start_time'],
        end_time = json['returnData']['end_time'],
        cnts = json['returnData']['cnts'],
        rows = (json['returnData']['rows'] as List) == null ? null : (json['returnData']['rows'] as List)
            .map((json) => new statusQueryRows.fromJson(json))
            .toList();
}

class statusQueryRows {
  var is_private;
  var category;
  var desc;
  var push_status;

  statusQueryRows({is_private, category, desc, push_status});

  factory statusQueryRows.fromJson(Map<String, dynamic> json) {
    return statusQueryRows(
        is_private : json['is_private'],
        category : json['category'],
        desc : json['desc'],
        push_status : json['push_status']
    );
  }
}

class unReadCountResp extends commonResp{
  var public_cnts;
  var private_cnts;
  var total_cnts;
  List<unReadCountRows> ?rows;

  unReadCountResp.fromJson(Map<String, dynamic> json)
      : public_cnts = json['returnData']['public_cnts'],
        private_cnts = json['returnData']['private_cnts'],
        total_cnts = json['returnData']['total_cnts'],
        rows = (json['returnData']['rows'] as List) == null ? null : (json['returnData']['rows'] as List)
            .map((json) => new unReadCountRows.fromJson(json))
            .toList();
}

class unReadCountRows {
  var category;
  var count;
  var is_private;

  unReadCountRows({category, count, desc, is_private});

  factory unReadCountRows.fromJson(Map<String, dynamic> json) {
    return unReadCountRows(
        category : json['category'],
        count : json['count'],
        is_private : json['is_private']
    );
  }
}

class bindingQueryResp extends commonResp{
  var cnts;
  List<bindingDevice> ?device;
  List<bindingDomainKey> ?domain_key;

  bindingQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device = (json['returnData']['device'] as List) == null ? null : (json['returnData']['device'] as List)
            .map((json) => new bindingDevice.fromJson(json))
            .toList(),
        domain_key = (json['returnData']['domain_key'] as List) == null ? null : (json['returnData']['domain_key'] as List)
            .map((json) => new bindingDomainKey.fromJson(json))
            .toList();
}

class bindingDevice {
  var serial_no;
  var domain_key;

  bindingDevice({serial_no, domain_key});

  factory bindingDevice.fromJson(Map<String, dynamic> json) {
    return bindingDevice(
        serial_no : json['serial_no'],
        domain_key : json['domain_key']
    );
  }
}

class bindingDomainKey {
  var serial_no;
  var device_uuid;

  bindingDomainKey({serial_no, device_uuid});

  factory bindingDomainKey.fromJson(Map<String, dynamic> json) {
    return bindingDomainKey(
        serial_no : json['serial_no'],
        device_uuid : json['device_uuid']
    );
  }
}

==> 1.0.3.tar.gz: lib/model/api_resp.dart <==
class commonResp {
  late int sequence;
  late String returnCode;
  late String returnMsg;

  commonResp();

  commonResp.fromJson(Map<String, dynamic> json)
      : sequence = json['sequence'],
        returnCode = json['returnCode'],
        returnMsg = json['returnCode'];
}

class getUUIDResp extends commonResp{
  var cnts;
  var device_uuid;
  var device_id;

  getUUIDResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device_uuid = json['returnData']['device_uuid'],
        device_id = json['returnData']['device_id'],
        super.fromJson(json);
}

class infoUpdateResp extends commonResp{
  var cnts;
  var device_uuid;
  var device_id;

  infoUpdateResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device_uuid = json['returnData']['device_uuid'],
        device_id = json['returnData']['device_id'],
        super.fromJson(json);
}

class contentQueryResp extends commonResp{
  var cnts;
  var title;
  var message;
  var status_time;
  var content_type;
  var content;

  contentQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        title = json['returnData']['title'],
        message = json['returnData']['message'],
        status_time = json['returnData']['status_time'],
        content_type = json['returnData']['content_type'],
        content = json['returnData']['content'],
        super.fromJson(json);
}

class messageQueryResp extends commonResp{
  var cnts;
  List<messageQueryRows> ?rows;

  messageQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        rows = (json['returnData']['rows'] as List) == null ? null : (json['returnData']['rows'] as List)
            .map((json) => new messageQueryRows.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class messageQueryRows {
  var message_id;
  var is_private;
  var category;
  var title;
  var message;
  var param;
  var status_time;
  var date;
  var time;
  var is_read;

  messageQueryRows({message_id, is_private, category, title, message, param, status_time, date, time, is_read});

  factory messageQueryRows.fromJson(Map<String, dynamic> json) {
    return messageQueryRows(
        message_id : json['message_id'],
        is_private : json['is_private'],
        category : json['category'],
        title : json['title'],
        message : json['message'],
        param : json['param'],
        status_time : json['status_time'],
        date : json['date'],
        time : json['time'],
        is_read : json['is_read']
    );
  }
}

class statusQueryResp extends commonResp{
  var is_receive;
  var enable_curfew;
  var start_time;
  var end_time;
  var cnts;
  List<statusQueryRows> ?rows;

  statusQueryResp.fromJson(Map<String, dynamic> json)
      : is_receive = json['returnData']['is_receive'],
        enable_curfew = json['returnData']['enable_curfew'],
        start_time = json['returnData']['start_time'],
        end_time = json['returnData']['end_time'],
        cnts = json['returnData']['cnts'],
        rows = (json['returnData']['rows'] as List) == null ? null : (json['returnData']['rows'] as List)
            .map((json) => new statusQueryRows.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class statusQueryRows {
  var is_private;
  var category;
  var desc;
  var push_status;

  statusQueryRows({is_private, category, desc, push_status});

  factory statusQueryRows.fromJson(Map<String, dynamic> json) {
    return statusQueryRows(
        is_private : json['is_private'],
        category : json['category'],
        desc : json['desc'],
        push_status : json['push_status']
    );
  }
}

class unReadCountResp extends commonResp{
  var public_cnts;
  var private_cnts;
  var total_cnts;
  List<unReadCountRows> ?rows;

  unReadCountResp.fromJson(Map<String, dynamic> json)
      : public_cnts = json['returnData']['public_cnts'],
        private_cnts = json['returnData']['private_cnts'],
        total_cnts = json['returnData']['total_cnts'],
        rows = (json['returnData']['rows'] as List) == null ? null : (json['returnData']['rows'] as List)
            .map((json) => new unReadCountRows.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class unReadCountRows {
  var category;
  var count;
  var is_private;

  unReadCountRows({category, count, desc, is_private});

  factory unReadCountRows.fromJson(Map<String, dynamic> json) {
    return unReadCountRows(
        category : json['category'],
        count : json['count'],
        is_private : json['is_private']
    );
  }
}

class bindingQueryResp extends commonResp{
  var cnts;
  List<bindingDevice> ?device;
  List<bindingDomainKey> ?domain_key;

  bindingQueryResp.fromJson(Map<String, dynamic> json)
      : cnts = json['returnData']['cnts'],
        device = (json['returnData']['device'] as List) == null ? null : (json['returnData']['device'] as List)
            .map((json) => new bindingDevice.fromJson(json))
            .toList(),
        domain_key = (json['returnData']['domain_key'] as List) == null ? null : (json['returnData']['domain_key'] as List)
            .map((json) => new bindingDomainKey.fromJson(json))
            .toList(),
        super.fromJson(json);
}

class bindingDevice {
  var serial_no;
  var domain_key;

  bindingDevice({serial_no, domain_key});

  factory bindingDevice.fromJson(Map<String, dynamic> json) {
    return bindingDevice(
        serial_no : json['serial_no'],
        domain_key : json['domain_key']
    );
  }
}

class bindingDomainKey {
  var serial_no;
  var device_uuid;

  bindingDomainKey({serial_no, device_uuid});

  factory bindingDomainKey.fromJson(Map<String, dynamic> json) {
    return bindingDomainKey(
        serial_no : json['serial_no'],
        device_uuid : json['device_uuid']
    );
  }
}
